package cz.cvut.felk.cs.atg.messenger.client;

import java.io.IOException;
import java.net.Socket;
import java.util.logging.Logger;

@SuppressWarnings("SocketOpenedButNotSafelyClosed")
public class MessengerClient {

    private static final Logger LOGGER = Logger.getLogger("MessengerClient");

    private final String address;
    private final int port;

    private Socket socket;

    public MessengerClient(String address, int port) {
        this.address = address;
        this.port = port;
    }

    public void start() throws IOException {
        socket = new Socket(address, port);
        LOGGER.finest("Socket started...");
    }

    public void write(byte[] data) throws IOException {
        if(socket != null){
            LOGGER.finest("Writing data...");
            socket.getOutputStream().write(data);
        } else {
            throw new IOException("Socket is not open yet");
        }
    }

    public void close() throws IOException {
        socket.close();
    }

    public static void main(String[] args) throws IOException {
        if(args.length != 2){
            LOGGER.warning("Usage: java MessagerClient <server address> <server port>");
            System.exit(1);
        }
        MessengerClient client = new MessengerClient(args[0], Integer.parseInt(args[1]));
        client.start();

        client.write("Hello world".getBytes());
        client.close();
    }
}
